@@ -55,7 +55,7 @@ private:
      */
     static inline float reduce(uint32_t val)
     {
-        // FIXME
+        // FIXME may not be fully portable
         // This code assumes IEEE-754 floating point representation
         // and same endianness for integers and floats
         const uint32_t mantissa = val & 0x807F0000; // Keep only most significant bits
@@ -85,9 +85,24 @@ public:
 class Filter8580 : public Filter
 {
 private:
+    /// Cutoff frequency in Hertz
     double highFreq;
-    float Vlp, Vbp, Vhp;
-    float w0, _1_div_Q;
+
+    /// Lowpass filter voltage
+    float Vlp;
+
+    /// Bandpass filter voltage
+    float Vbp;
+
+    /// Highpass filter voltage
+    float Vhp;
+
+    float w0;
+
+    /// Resonance parameter
+    float _1_div_Q;
+
+    /// External input voltage
     int ve;
 
     antiDenormalNoise noise;
@@ -107,7 +122,7 @@ public:
     /**
      * Set filter cutoff frequency.
      */
-    void updatedCenterFrequency() { w0 = (float)(2. * M_PI * highFreq * fc / 2047. / 1e6); }
+    void updatedCenterFrequency() { w0 = static_cast<float>(2. * M_PI * highFreq * fc / 2047. / 1e6); }
 
     /**
      * Set filter resonance.
@@ -116,7 +131,7 @@ public:
      *
      * 1/Q = 2^(1/2)*2^(-x/8) = 2^(1/2 - x/8) = 2^((4 - x)/8)
      */
-    void updatedResonance() { _1_div_Q = (float)pow(2., (4 - res) / 8.); }
+    void updatedResonance() { _1_div_Q = static_cast<float>(pow(2., (4 - res) / 8.)); }
 
     void input(int input) { ve = input << 4; }
 
@@ -155,14 +170,8 @@ int Filter8580::clock(int voice1, int voice2, int voice3)
 
     // NB! Voice 3 is not silenced by voice3off if it is routed
     // through the filter.
-    if (filt3)
-    {
-        Vi += voice3;
-    }
-    else if (!voice3off)
-    {
-        Vo += voice3;
-    }
+    if (filt3) Vi += voice3;
+    else if (!voice3off) Vo += voice3;
 
     (filtE ? Vi : Vo) += ve;
 
@@ -174,7 +183,7 @@ int Filter8580::clock(int voice1, int voice2, int voice3)
     assert(std::fpclassify(Vbp) != FP_SUBNORMAL);
     assert(std::fpclassify(Vhp) != FP_SUBNORMAL);
 
-    float Vof = (float)Vo;
+    float Vof = static_cast<float>(Vo);
 
     if (lp)
     {
@@ -191,7 +200,7 @@ int Filter8580::clock(int voice1, int voice2, int voice3)
         Vof += Vhp;
     }
 
-    return (int) Vof * vol >> 4;
+    return static_cast<int>(Vof) * vol >> 4;
 }
 
 } // namespace reSIDfp
