@@ -225,7 +225,7 @@ void MOS6510::interruptsAndNextOpcode()
         {
             const event_clock_t cycles = eventContext.getTime (EVENT_CLOCK_PHI2);
             fprintf (m_fdbg, "****************************************************\n");
-            fprintf (m_fdbg, " interrupt (%d)\n", (int)cycles);
+            fprintf (m_fdbg, " interrupt (%d)\n", static_cast<int>(cycles));
             fprintf (m_fdbg, "****************************************************\n");
             MOS6510Debug::DumpState(cycles, *this);
         }
